'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var History = function () {
  function History(onNavigation) {
    _classCallCheck(this, History);

    this.onNavigation = onNavigation;
    this._window = window;
    this.strategy = this._strategy();
    this.onChange = this._onChange.bind(this);
  }

  _createClass(History, [{
    key: '_strategy',
    value: function _strategy() {
      if (this._window.history && this._window.history.pushState) return 'push';
      if ('onhashchange' in this._window) return 'hash';
      return 'poll';
    }

    /* url->href */

  }, {
    key: 'externalizeUrl',
    value: function externalizeUrl(basePath, path) {
      if (this.strategy === 'push') {
        return path;
      }
      return basePath + '#!' + path.slice(basePath.length);
    }

    /* href->url */

  }, {
    key: 'internalizeUrl',
    value: function internalizeUrl(basePath, path) {
      if (this.strategy === 'push') {
        return path;
      }
      var root = basePath + '#!';
      if (path.indexOf(root) !== 0) {
        return path;
      }
      return '' + basePath + path.slice(root.length);
    }
  }, {
    key: '_onChange',
    value: function _onChange() {
      var path = void 0;
      switch (this.strategy) {
        case 'push':
          var _window$location = this._window.location,
              href = _window$location.href,
              origin = _window$location.origin;

          path = href.slice(origin.length);
          break;
        case 'hash':
        case 'poll':
          path = this._window.location.hash.slice(2);
      }
      this.onNavigation(path);
    }
  }, {
    key: 'update',
    value: function update(path, title, replace) {
      switch (this.strategy) {
        case 'push':
          if (replace) {
            this._window.history.replaceState({}, title, path);
          } else {
            this._window.history.pushState({}, title, path);
          }
          break;
        case 'hash':
        case 'poll':
          this._window.location.hash = '#!' + path;
      }
    }
  }, {
    key: 'attach',
    value: function attach() {
      var _this = this;

      switch (this.strategy) {
        case 'push':
          this._window.addEventListener('popstate', this.onChange);
          break;
        case 'hash':
          this._window.addEventListener('hashchange', this.onChange);
          break;
        case 'poll':
          this._hashPoll = setTimeout(function () {
            var prev = _this._previousHashPoll;
            var hash = _this._window.location.hash;
            if (prev && prev !== hash) {
              _this.onChange();
            }
            _this._previousHashPoll = hash;
          }, 300);
      }
    }
  }, {
    key: 'detach',
    value: function detach() {
      switch (this.strategy) {
        case 'push':
          this._window.removeEventListener('popstate', this.onChange);
          break;
        case 'hash':
          this._window.removeEventListener('hashchange', this.onChange);
          break;
        case 'poll':
          clearInterval(this._hashPoll);
      }
    }
  }]);

  return History;
}();

exports.default = History;
//# sourceMappingURL=history.js.map
